@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::clean;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::App::Command::clean::VERSION = '4.101612';
+}
 # ABSTRACT: clean up after build, test, or install
 use Dist::Zilla::App -command;
 
@@ -13,19 +15,7 @@ sub abstract { 'clean up after build, test, or install' }
 sub execute {
   my ($self, $opt, $arg) = @_;
 
-  require File::Path;
-  for my $x (grep { -e } '.build', glob($self->zilla->name . '-*')) {
-    $self->log("clean: removing $x");
-    File::Path::rmtree($x);
-  };
-
-  # removing leftovers
-  my @temps =
-    File::Find::Rule
-    ->file
-    ->name( qr/~$/ )
-    ->in('.');
-  unlink @temps;
+  $self->zilla->clean;
 }
 
 1;
@@ -39,24 +29,16 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 SYNOPSIS
 
-Removes some files that are created during build, test, and install.
+  dzil clean
 
-    dzil clean
-
-=head1 REMOVED FILES
-
-    ^.build
-    ^<distribution-name>-*
-
-ie:
-
-    removing .build
-    removing Foo-Bar-1.09010
-    removing Foo-Bar-1.09010.tar.gz
+This command removes some files that are created during build, test, and
+install.  It's a very thin layer over the C<L<clean|Dist::Zilla/clean>> method
+on the Dist::Zilla object.  The documentation for that method gives more
+information about the files that will be removed.
 
 =head1 AUTHOR
 
