@@ -1,15 +1,26 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command::release;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::App::Command::release::VERSION = '4.101612';
+}
 # ABSTRACT: release your dist to the CPAN
 use Dist::Zilla::App -command;
 
 
 sub abstract { 'release your dist' }
 
+sub opt_spec {
+  [ 'trial' => 'build a trial release that PAUSE will not index' ],
+}
+
 sub execute {
   my ($self, $opt, $arg) = @_;
+
+  my $zilla = $self->zilla;
+
+  $zilla->is_trial(1) if $opt->trial;
+
   $self->zilla->release;
 }
 
@@ -24,16 +35,18 @@ Dist::Zilla::App::Command::release - release your dist to the CPAN
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 SYNOPSIS
 
-Use ReleasePlugin(s) to release your distribution in many ways.
+  dzil release
 
-    dzil release
+  dzil release --trial
 
-Put some plugins in your F<dist.ini> that perform
-L<Dist::Zilla::Role::Releaser>, such as L<Dist::Zilla::Plugin::UploadToCPAN>
+This command is a very, very thin wrapper around the
+C<L<release|Dist::Zilla/release>> method on the Dist::Zilla object.  It will
+build, archive, and release your distribution using your Releaser plugins.  The
+only option, C<--trial>, will cause it to build a trial build.
 
 =head1 AUTHOR
 
