@@ -1,5 +1,7 @@
 package Dist::Zilla::File::OnDisk;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::File::OnDisk::VERSION = '4.101612';
+}
 # ABSTRACT: a file that comes from your filesystem
 use Moose;
 
@@ -27,6 +29,12 @@ sub _read_file {
 
   my $fname = $self->_original_name;
   open my $fh, '<', $fname or die "can't open $fname for reading: $!";
+
+  # This is needed or \r\n is filtered to be just \n on win32.
+  # Maybe :raw:utf8, not sure.
+  #     -- Kentnl - 2010-06-10
+  binmode $fh, ':raw';
+
   my $content = do { local $/; <$fh> };
 }
 
@@ -45,7 +53,7 @@ Dist::Zilla::File::OnDisk - a file that comes from your filesystem
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
