@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::AutoVersion;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::AutoVersion::VERSION = '4.101612';
+}
 # ABSTRACT: take care of numbering versions so you don't have to
 use Moose;
 with(
@@ -7,7 +9,7 @@ with(
   'Dist::Zilla::Role::TextTemplate',
 );
 
-use DateTime ();
+use DateTime 0.44 (); # CLDR fixes
 
 
 
@@ -30,7 +32,9 @@ has format => (
   is       => 'ro',
   isa      => 'Str',
   required => 1,
-  default  => q[{{ $major }}.{{ cldr('yyDDD') }}{{ sprintf '%01u', ($ENV{N} || 0) }}],
+  default  => q<{{ $major }}.{{ cldr('yyDDD') }}>
+            . q<{{ sprintf('%01u', ($ENV{N} || 0)) }}>
+            . q<{{$ENV{DEV} ? (sprintf '_%03u', $ENV{DEV}) : ''}}>
 );
 
 sub provide_version {
@@ -45,6 +49,10 @@ sub provide_version {
       cldr  => sub { $now->format_cldr($_[0]) },
     },
   );
+
+  $self->log_debug([ 'providing version %s', $version ]);
+
+  return $version;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -60,7 +68,7 @@ Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
@@ -86,7 +94,9 @@ which consult the L<DateTime> documentation).
 
 The default value is:
 
-  {{ $major }}.{{ cldr('yyDDD') }}{{ sprintf '%01u', ($ENV{N} || 0) }}
+  {{ $major }}.{{ cldr('yyDDD') }}
+  {{ sprintf('%01u', ($ENV{N} || 0)) }}
+  {{$ENV{DEV} ? (sprintf '_%03u', $ENV{DEV}) : ''}}
 
 =head1 AUTHOR
 
