@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::InlineFiles;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::InlineFiles::VERSION = '4.101612';
+}
 # ABSTRACT: files in a data section
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
 
-use Data::Section -setup;
+use Data::Section 0.004 -setup; # fixed header_re
 use Dist::Zilla::File::InMemory;
 
 sub gather_files {
@@ -40,7 +42,7 @@ Dist::Zilla::Plugin::InlineFiles - files in a data section
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
