@@ -1,17 +1,20 @@
 package Dist::Zilla::Plugin::MakeMaker;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.101612';
+}
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::BuildRunner';
-with 'Dist::Zilla::Role::FixedPrereqs';
+with 'Dist::Zilla::Role::PrereqSource';
 with 'Dist::Zilla::Role::InstallTool';
-with 'Dist::Zilla::Role::MetaProvider';
 with 'Dist::Zilla::Role::TestRunner';
 with 'Dist::Zilla::Role::TextTemplate';
 
 
+use Config;
+
 use Data::Dumper ();
 use List::MoreUtils qw(any uniq);
 
@@ -25,14 +28,27 @@ use warnings;
 
 {{ $perl_prereq ? qq{ BEGIN { require $perl_prereq; } } : ''; }}
 
-use ExtUtils::MakeMaker 6.11;
+use ExtUtils::MakeMaker {{ $eumm_version }};
 
 {{ $share_dir_block[0] }}
 
 my {{ $WriteMakefileArgs }}
 
-delete $WriteMakefileArgs{LICENSE}
-  unless eval { ExtUtils::MakeMaker->VERSION(6.31) };
+unless ( eval { ExtUtils::MakeMaker->VERSION(6.56) } ) {
+  my $br = delete $WriteMakefileArgs{BUILD_REQUIRES};
+  my $pp = $WriteMakefileArgs{PREREQ_PM};
+  for my $mod ( keys %$br ) {
+    if ( exists $pp->{$mod} ) {
+      $pp->{$mod} = $br->{$mod} if $br->{$mod} > $pp->{$mod};
+    }
+    else {
+      $pp->{$mod} = $br->{$mod};
+    }
+  }
+}
+
+delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
+  unless eval { ExtUtils::MakeMaker->VERSION(6.52) };
 
 WriteMakefile(%WriteMakefileArgs);
 
@@ -40,18 +56,20 @@ WriteMakefile(%WriteMakefileArgs);
 
 |;
 
-sub metadata {
+sub register_prereqs {
   my ($self) = @_;
 
-  my @dir_plugins = $self->zilla->plugins
-    ->grep( sub { $_->isa('Dist::Zilla::Plugin::InstallDirs') })
-    ->flatten;
+  $self->zilla->register_prereqs(
+    { phase => 'configure' },
+    'ExtUtils::MakeMaker' => $self->eumm_version,
+  );
 
-  return {} unless uniq map {; $_->share->flatten } @dir_plugins;
+  return unless $self->zilla->_share_dir;
 
-  return {
-    configure_requires => { 'File::ShareDir::Install' => 0 },
-  };
+  $self->zilla->register_prereqs(
+    { phase => 'configure' },
+    'File::ShareDir::Install' => 0.03,
+  );
 }
 
 sub setup_installer {
@@ -59,22 +77,10 @@ sub setup_installer {
 
   (my $name = $self->zilla->name) =~ s/-/::/g;
 
-  # XXX: SHAMELESSLY COPIED AND PASTED INTO ModuleBuild -- rjbs, 2010-01-05
-  my @dir_plugins = $self->zilla->plugins
-    ->grep( sub { $_->isa('Dist::Zilla::Plugin::InstallDirs') })
-    ->flatten;
+  my @exe_files =
+    $self->zilla->find_files(':ExecFiles')->map(sub { $_->name })->flatten;
 
-  my @bin_dirs    = uniq map {; $_->bin->flatten   } @dir_plugins;
-  my @share_dirs  = uniq map {; $_->share->flatten } @dir_plugins;
-
-  confess "can't install more than one ShareDir" if @share_dirs > 1;
-
-  my @exe_files = $self->zilla->files
-    ->grep(sub { my $f = $_; any { $f->name =~ qr{^\Q$_\E[\\/]} } @bin_dirs; })
-    ->map( sub { $_->name })
-    ->flatten;
-
-  confess "can't install files with whitespace in their names"
+  $self->log_fatal("can't install files with whitespace in their names")
     if grep { /\s/ } @exe_files;
 
   my %test_dirs;
@@ -87,15 +93,30 @@ sub setup_installer {
 
   my @share_dir_block = (q{}, q{});
 
-  if ($share_dirs[0]) {
-    my $share_dir = quotemeta $share_dirs[0];
+  if (my $share_dir = $self->zilla->_share_dir) {
+    my $share_dir = quotemeta $share_dir;
     @share_dir_block = (
       qq{use File::ShareDir::Install;\ninstall_share "$share_dir";\n},
-      qq{package MY;\nuse File::ShareDir::Install qw(postamble);\n},
+      qq{package\nMY;\nuse File::ShareDir::Install qw(postamble);\n},
     );
   }
 
-  my $prereq = $self->zilla->prereq;
+  my $prereqs = $self->zilla->prereqs;
+  my $perl_prereq = $prereqs->requirements_for(qw(runtime requires))
+                  ->as_string_hash->{perl};
+
+  my $prereqs_dump = sub {
+    $prereqs->requirements_for(@_)
+            ->clone
+            ->clear_requirement('perl')
+            ->as_string_hash;
+  };
+
+  my $build_prereq
+    = $prereqs->requirements_for(qw(build requires))
+    ->clone
+    ->add_requirements($prereqs->requirements_for(qw(test requires)))
+    ->as_string_hash;
 
   my %write_makefile_args = (
     DISTNAME  => $self->zilla->name,
@@ -105,21 +126,28 @@ sub setup_installer {
     VERSION   => $self->zilla->version,
     LICENSE   => $self->zilla->license->meta_yml_name,
     EXE_FILES => [ @exe_files ],
-    PREREQ_PM    => {
-      map {; $_ => $prereq->{$_} } grep { $_ ne 'perl' } keys %$prereq
-    },
+
+    CONFIGURE_REQUIRES => $prereqs_dump->(qw(configure requires)),
+    BUILD_REQUIRES     => $build_prereq,
+    PREREQ_PM          => $prereqs_dump->(qw(runtime   requires)),
+
     test => { TESTS => join q{ }, sort keys %test_dirs },
   );
 
+  $self->__write_makefile_args(\%write_makefile_args);
+
   my $makefile_args_dumper = Data::Dumper->new(
     [ \%write_makefile_args ],
     [ '*WriteMakefileArgs' ],
   );
+  $makefile_args_dumper->Sortkeys( 1 );
+  $makefile_args_dumper->Indent( 1 );
 
   my $content = $self->fill_in_string(
     $template,
     {
-      perl_prereq => \($self->prereq->{perl}),
+      eumm_version      => \($self->eumm_version),
+      perl_prereq       => \$perl_prereq,
       share_dir_block   => \@share_dir_block,
       WriteMakefileArgs => \($makefile_args_dumper->Dump),
     },
@@ -134,39 +162,42 @@ sub setup_installer {
   return;
 }
 
+# XXX:  Just here to facilitate testing. -- rjbs, 2010-03-20
+has __write_makefile_args => (
+  is   => 'rw',
+  isa  => 'HashRef',
+);
+
+has 'make_path' => (
+  isa => 'Str',
+  is  => 'ro',
+  default => $Config{make} || 'make',
+);
+
 sub build {
   my $self = shift;
+
+  my $make = $self->make_path;
   system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
-  system('make')               and die "error running make\n";
+  system($make)                and die "error running $make\n";
+
   return;
 }
 
 sub test {
   my ( $self, $target ) = @_;
-  ## no critic Punctuation
+
+  my $make = $self->make_path;
   $self->build;
-  system('make test') and die "error running make test\n";
+  system($make, 'test') and die "error running $make test\n";
+
   return;
 }
 
-sub prereq {
-  my ($self) = @_;
-
-  my $has_share = $self->zilla->plugins
-    ->grep(sub { $_->isa('Dist::Zilla::Plugins::InstallDirs') })
-    ->grep(sub { $_->share->length > 0 })
-    ->length;
-
-  return {
-    'ExtUtils::MakeMaker'     => $self->eumm_version,
-    ($has_share ? ('File::ShareDir::Install' => 0.03) : ()),
-  };
-}
-
 has 'eumm_version' => (
   isa => 'Str',
   is  => 'rw',
-  default => '6.11',
+  default => '6.31',
 );
 
 __PACKAGE__->meta->make_immutable;
@@ -182,7 +213,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
