@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::Readme;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Plugin::Readme::VERSION = '4.101612';
+}
 # ABSTRACT: build a README file
 use Moose;
 use Moose::Autobox;
@@ -14,12 +16,13 @@ sub gather_files {
 
   my $template = q|
 
-This archive contains the distribution {{ $dist->name }}, version
-{{ $dist->version }}:
+This archive contains the distribution {{ $dist->name }},
+version {{ $dist->version }}:
 
   {{ $dist->abstract }}
 
 {{ $dist->license->notice }}
+
 |;
 
   my $content = $self->fill_in_string(
@@ -49,7 +52,7 @@ Dist::Zilla::Plugin::Readme - build a README file
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
