@@ -1,8 +1,7 @@
-use strict;
-use warnings;
-
 package Dist::Zilla::Role::BeforeRelease;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Role::BeforeRelease::VERSION = '4.101612';
+}
 # ABSTRACT: something that runs before release really begins
 
 use Moose::Role;
@@ -22,7 +21,7 @@ Dist::Zilla::Role::BeforeRelease - something that runs before release really beg
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
