@@ -1,16 +1,20 @@
 package Dist::Zilla::Role::FileMunger;
-our $VERSION = '1.100160';
+BEGIN {
+  $Dist::Zilla::Role::FileMunger::VERSION = '4.101612';
+}
 # ABSTRACT: something that alters a file's destination or content
 use Moose::Role;
 use Moose::Autobox;
 
 
 with 'Dist::Zilla::Role::Plugin';
-requires 'munge_file';
 
 sub munge_files {
   my ($self) = @_;
 
+  $self->log_fatal("no munge_file behavior implemented!")
+    unless $self->can('munge_file');
+
   $self->munge_file($_) for $self->zilla->files->flatten;
 }
 
@@ -26,7 +30,7 @@ Dist::Zilla::Role::FileMunger - something that alters a file's destination or co
 
 =head1 VERSION
 
-version 1.100160
+version 4.101612
 
 =head1 DESCRIPTION
 
